.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.sorting
======================

.. automodule:: sphinx_gallery.sorting

   
   
   

   
   

   Classes
   -------

   
   .. autoclass:: ExampleTitleSortKey
      :members:

   .. _sphx_glr_backref_sphinx_gallery.sorting.ExampleTitleSortKey:

   .. minigallery:: sphinx_gallery.sorting.ExampleTitleSortKey
       :add-heading:
   .. autoclass:: ExplicitOrder
      :members:

   .. _sphx_glr_backref_sphinx_gallery.sorting.ExplicitOrder:

   .. minigallery:: sphinx_gallery.sorting.ExplicitOrder
       :add-heading:
   .. autoclass:: FileNameSortKey
      :members:

   .. _sphx_glr_backref_sphinx_gallery.sorting.FileNameSortKey:

   .. minigallery:: sphinx_gallery.sorting.FileNameSortKey
       :add-heading:
   .. autoclass:: FileSizeSortKey
      :members:

   .. _sphx_glr_backref_sphinx_gallery.sorting.FileSizeSortKey:

   .. minigallery:: sphinx_gallery.sorting.FileSizeSortKey
       :add-heading:
   .. autoclass:: NumberOfCodeLinesSortKey
      :members:

   .. _sphx_glr_backref_sphinx_gallery.sorting.NumberOfCodeLinesSortKey:

   .. minigallery:: sphinx_gallery.sorting.NumberOfCodeLinesSortKey
       :add-heading:
   
   

   
   
   